colour.models.dataset.eci_rgb_v2 Module — Colour 0.3.0 documentation

# colour.models.dataset.eci_rgb_v2 Module

## ECI RGB v2 Colourspace

Defines the ECI RGB v2 colourspace:

- `ECI_RGB_V2_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.eci.org/_media/downloads/icc_profiles_from_eci/ecirgbv20.zip (Last accessed 13 April 2014)

`colour.models.dataset.eci_rgb_v2.` `ECI_RGB_V2_PRIMARIES` = array([[ 0.67010309, 0.32989691], [ 0.20990566, 0.70990566], [ 0.14006179, 0.08032956]])

  ECI RGB v2 colourspace primaries.

  ECI_RGB_V2_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.eci_rgb_v2.` `ECI_RGB_V2_WHITEPOINT` = (0.34567, 0.3585)

  ECI RGB v2 colourspace whitepoint.

  ECI_RGB_V2_WHITEPOINT : tuple

`colour.models.dataset.eci_rgb_v2.` `ECI_RGB_V2_TO_XYZ_MATRIX` = array([[ 6.50212758e-01, 1.77962861e-01, 1.36036375e-01], [ 3.20104742e-01, 6.01874395e-01, 7.80208624e-02], [ -5.38634415e-17, 6.79858121e-02, 7.57202472e-01]])

  ECI RGB v2 colourspace to CIE XYZ colourspace matrix.

  ECI_RGB_V2_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.eci_rgb_v2.` `XYZ_TO_ECI_RGB_V2_MATRIX` = array([[ 1.78246197, -0.49664841, -0.26905714], [-0.95915956, 1.94829285, -0.02842951], [ 0.08611863, -0.17492847, 1.32320329]])

  CIE XYZ colourspace to ECI RGB v2 colourspace matrix.

  XYZ_TO_ECI_RGB_V2_MATRIX : array_like, (3, 3)

`colour.models.dataset.eci_rgb_v2.` `ECI_RGB_V2_TRANSFER_FUNCTION`(x)

  Transfer function from linear to ECI RGB v2 colourspace.

  ECI_RGB_V2_TRANSFER_FUNCTION : object

`colour.models.dataset.eci_rgb_v2.` `ECI_RGB_V2_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from ECI RGB v2 colourspace to linear.

  ECI_RGB_V2_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.eci_rgb_v2.` `ECI_RGB_V2_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1dfd0>

  ECI RGB v2 colourspace.

  ECI_RGB_V2_COLOURSPACE : RGB_Colourspace